@@ -485,6 +485,11 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
       checkInactivity();
    }
 
+   @Override
+   public void close() {
+      destroy();
+   }
+
    private void checkInactivity() {
       if (!this.useKeepAlive) {
          return;
@@ -778,7 +783,7 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
          if (me != null) {
             //filter it like the other protocols
             if (!(me instanceof ActiveMQRemoteDisconnectException)) {
-               ActiveMQClientLogger.LOGGER.connectionFailureDetected(this.transportConnection.getRemoteAddress(), me.getMessage(), me.getType());
+               ActiveMQClientLogger.LOGGER.connectionFailureDetected(this.transportConnection.getProtocolConnection().getProtocolName(), this.transportConnection.getRemoteAddress(), me.getMessage(), me.getType());
             }
          }
          try {
@@ -1026,12 +1031,9 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
       this.maxInactivityDuration = inactivityDuration;
 
       if (this.useKeepAlive) {
-         ttlCheck = protocolManager.getScheduledPool().schedule(new Runnable() {
-            @Override
-            public void run() {
-               if (inactivityDuration >= 0) {
-                  connectionEntry.ttl = inactivityDuration;
-               }
+         ttlCheck = protocolManager.getScheduledPool().schedule(() -> {
+            if (inactivityDuration >= 0) {
+               connectionEntry.ttl = inactivityDuration;
             }
          }, inactivityDurationInitialDelay, TimeUnit.MILLISECONDS);
          checkInactivity();
