@@ -61,6 +61,7 @@ import org.apache.activemq.artemis.json.JsonArrayBuilder;
 import org.apache.activemq.artemis.json.JsonObjectBuilder;
 import org.apache.activemq.artemis.logs.AuditLogger;
 import org.apache.activemq.artemis.selector.filter.Filterable;
+import org.apache.activemq.artemis.utils.CompositeAddress;
 import org.apache.activemq.artemis.utils.JsonLoader;
 import org.apache.activemq.artemis.utils.collections.LinkedListIterator;
 import org.slf4j.Logger;
@@ -1088,7 +1089,7 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
          Map<String, Long> result = new HashMap<>();
          try {
             Filter filter = FilterImpl.createFilter(filterStr);
-            SimpleString groupByProperty = SimpleString.toSimpleString(groupByPropertyStr);
+            SimpleString groupByProperty = SimpleString.of(groupByPropertyStr);
             if (filter == null && groupByProperty == null) {
                result.put(null, getMessageCount());
             } else {
@@ -1141,7 +1142,7 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
          Map<String, Long> result = new HashMap<>();
          try {
             Filter filter = FilterImpl.createFilter(filterStr);
-            SimpleString groupByProperty = SimpleString.toSimpleString(groupByPropertyStr);
+            SimpleString groupByProperty = SimpleString.of(groupByPropertyStr);
             if (filter == null && groupByProperty == null) {
                result.put(null, (long) getDeliveringCount());
             } else {
@@ -1299,7 +1300,7 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
 
                @Override
                public SimpleString getFilterString() {
-                  return new SimpleString("custom filter for MESSAGEID= messageID");
+                  return SimpleString.of("custom filter for MESSAGEID= messageID");
                }
             };
 
@@ -1346,7 +1347,7 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
 
          clearIO();
          try {
-            Binding binding = server.getPostOffice().getBinding(new SimpleString(otherQueueName));
+            Binding binding = server.getPostOffice().getBinding(SimpleString.of(otherQueueName));
 
             if (binding == null) {
                throw ActiveMQMessageBundle.BUNDLE.noQueueFound(otherQueueName);
@@ -1390,7 +1391,7 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
          try {
             Filter filter = FilterImpl.createFilter(filterStr);
 
-            Binding binding = server.getPostOffice().getBinding(new SimpleString(otherQueueName));
+            Binding binding = server.getPostOffice().getBinding(SimpleString.of(otherQueueName));
 
             if (binding == null) {
                throw ActiveMQMessageBundle.BUNDLE.noQueueFound(otherQueueName);
@@ -1456,7 +1457,7 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
             AuditLogger.sendMessageThroughManagement(queue, headers, type, body, durable, user, "****");
          }
          try {
-            String s = sendMessage(queue.getAddress(), server, headers, type, body, durable, user, password, createMessageId, queue.getID());
+            String s = sendMessage(CompositeAddress.toFullyQualified(queue.getAddress(), queue.getName()), server, headers, type, body, durable, user, password, createMessageId);
             if (AuditLogger.isResourceLoggingEnabled()) {
                AuditLogger.sendMessageSuccess(queue.getName().toString(), user);
             }
@@ -1846,7 +1847,7 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
 
       clearIO();
       try {
-         queue.resetGroup(SimpleString.toSimpleString(groupID));
+         queue.resetGroup(SimpleString.of(groupID));
       } finally {
          blockOnIO();
       }
