@@ -16,18 +16,22 @@
  */
 package org.apache.activemq.artemis.core.config;
 
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import org.apache.activemq.artemis.api.config.ActiveMQDefaultConfiguration;
 import org.apache.activemq.artemis.core.server.ComponentConfigurationRoutingType;
 import org.apache.activemq.artemis.utils.JsonLoader;
-import org.junit.Assert;
-import org.junit.Test;
-
+import org.junit.jupiter.api.Test;
 import org.apache.activemq.artemis.json.JsonObject;
 import org.apache.activemq.artemis.json.JsonObjectBuilder;
 import org.apache.activemq.artemis.json.JsonValue;
-import java.io.StringReader;
 
-import static org.hamcrest.Matchers.containsInAnyOrder;
+import java.io.StringReader;
+import java.util.Set;
 
 public class BridgeConfigurationTest {
 
@@ -37,36 +41,39 @@ public class BridgeConfigurationTest {
 
       BridgeConfiguration bridgeConfiguration = BridgeConfiguration.fromJSON(jsonString);
 
-      Assert.assertNotNull(bridgeConfiguration);
-      Assert.assertEquals("name", bridgeConfiguration.getName());
-      Assert.assertEquals("queue-name", bridgeConfiguration.getQueueName());
-      Assert.assertEquals("forwarding-address", bridgeConfiguration.getForwardingAddress());
-      Assert.assertEquals("filter-string", bridgeConfiguration.getFilterString());
-      Assert.assertArrayEquals(new String[]{"connector1", "connector2"},
+      assertNotNull(bridgeConfiguration);
+      assertEquals("name", bridgeConfiguration.getName());
+      assertEquals("queue-name", bridgeConfiguration.getQueueName());
+      assertEquals("forwarding-address", bridgeConfiguration.getForwardingAddress());
+      assertEquals("filter-string", bridgeConfiguration.getFilterString());
+      assertArrayEquals(new String[]{"connector1", "connector2"},
             bridgeConfiguration.getStaticConnectors().toArray());
-      Assert.assertEquals("dg", bridgeConfiguration.getDiscoveryGroupName());
-      Assert.assertTrue(bridgeConfiguration.isHA());
-      Assert.assertEquals("ClassName", bridgeConfiguration.getTransformerConfiguration().getClassName());
-      Assert.assertThat(bridgeConfiguration.getTransformerConfiguration().getProperties().keySet(), containsInAnyOrder("prop1", "prop2"));
-      Assert.assertEquals("val1", bridgeConfiguration.getTransformerConfiguration().getProperties().get("prop1"));
-      Assert.assertEquals("val2", bridgeConfiguration.getTransformerConfiguration().getProperties().get("prop2"));
-      Assert.assertEquals(1, bridgeConfiguration.getRetryInterval());
-      Assert.assertEquals(2.0, bridgeConfiguration.getRetryIntervalMultiplier(), 0);
-      Assert.assertEquals(3, bridgeConfiguration.getInitialConnectAttempts());
-      Assert.assertEquals(4, bridgeConfiguration.getReconnectAttempts());
-      Assert.assertEquals(5, bridgeConfiguration.getReconnectAttemptsOnSameNode());
-      Assert.assertTrue(bridgeConfiguration.isUseDuplicateDetection());
-      Assert.assertEquals(6, bridgeConfiguration.getConfirmationWindowSize());
-      Assert.assertEquals(7, bridgeConfiguration.getProducerWindowSize());
-      Assert.assertEquals(8, bridgeConfiguration.getClientFailureCheckPeriod());
-      Assert.assertEquals("user", bridgeConfiguration.getUser());
-      Assert.assertEquals("password", bridgeConfiguration.getPassword());
-      Assert.assertEquals(9, bridgeConfiguration.getConnectionTTL());
-      Assert.assertEquals(10, bridgeConfiguration.getMaxRetryInterval());
-      Assert.assertEquals(11, bridgeConfiguration.getMinLargeMessageSize());
-      Assert.assertEquals(12, bridgeConfiguration.getCallTimeout());
-      Assert.assertEquals(ComponentConfigurationRoutingType.MULTICAST, bridgeConfiguration.getRoutingType());
-      Assert.assertEquals(1, bridgeConfiguration.getConcurrency());
+      assertEquals("dg", bridgeConfiguration.getDiscoveryGroupName());
+      assertTrue(bridgeConfiguration.isHA());
+      assertEquals("ClassName", bridgeConfiguration.getTransformerConfiguration().getClassName());
+      Set keys = bridgeConfiguration.getTransformerConfiguration().getProperties().keySet();
+      assertTrue(keys.contains("prop1"), keys + " doesn't contain prop1");
+      assertTrue(keys.contains("prop2"), keys + " doesn't contain prop2");
+      assertEquals("val1", bridgeConfiguration.getTransformerConfiguration().getProperties().get("prop1"));
+      assertEquals("val2", bridgeConfiguration.getTransformerConfiguration().getProperties().get("prop2"));
+      assertEquals(1, bridgeConfiguration.getRetryInterval());
+      assertEquals(2.0, bridgeConfiguration.getRetryIntervalMultiplier(), 0);
+      assertEquals(3, bridgeConfiguration.getInitialConnectAttempts());
+      assertEquals(4, bridgeConfiguration.getReconnectAttempts());
+      assertEquals(5, bridgeConfiguration.getReconnectAttemptsOnSameNode());
+      assertTrue(bridgeConfiguration.isUseDuplicateDetection());
+      assertEquals(6, bridgeConfiguration.getConfirmationWindowSize());
+      assertEquals(7, bridgeConfiguration.getProducerWindowSize());
+      assertEquals(8, bridgeConfiguration.getClientFailureCheckPeriod());
+      assertEquals("user", bridgeConfiguration.getUser());
+      assertEquals("password", bridgeConfiguration.getPassword());
+      assertEquals(9, bridgeConfiguration.getConnectionTTL());
+      assertEquals(10, bridgeConfiguration.getMaxRetryInterval());
+      assertEquals(11, bridgeConfiguration.getMinLargeMessageSize());
+      assertEquals(12, bridgeConfiguration.getCallTimeout());
+      assertEquals(ComponentConfigurationRoutingType.MULTICAST, bridgeConfiguration.getRoutingType());
+      assertEquals(1, bridgeConfiguration.getConcurrency());
+      assertEquals(321, bridgeConfiguration.getPendingAckTimeout());
    }
 
    @Test
@@ -74,14 +81,14 @@ public class BridgeConfigurationTest {
       // create bc instance from a JSON object, all attributes are set
       JsonObject jsonObject = createFullJsonObject();
       BridgeConfiguration bridgeConfiguration = BridgeConfiguration.fromJSON(jsonObject.toString());
-      Assert.assertNotNull(bridgeConfiguration);
+      assertNotNull(bridgeConfiguration);
 
       // serialize it back to JSON
       String serializedBridgeConfiguration = bridgeConfiguration.toJSON();
       JsonObject serializedBridgeConfigurationJsonObject = JsonLoader.readObject(new StringReader(serializedBridgeConfiguration));
 
       // verify that the original JSON object is identical to the one serialized via the toJSON() method
-      Assert.assertEquals(jsonObject, serializedBridgeConfigurationJsonObject);
+      assertEquals(jsonObject, serializedBridgeConfigurationJsonObject);
    }
 
    @Test
@@ -92,24 +99,25 @@ public class BridgeConfigurationTest {
       JsonObject jsonObject = JsonLoader.readObject(new StringReader(jsonString));
 
       // the serialized JSON string should contain default values of primitive type fields
-      Assert.assertEquals("2000", jsonObject.get(BridgeConfiguration.RETRY_INTERVAL).toString());
-      Assert.assertEquals("1.0", jsonObject.get(BridgeConfiguration.RETRY_INTERVAL_MULTIPLIER).toString());
-      Assert.assertEquals("-1", jsonObject.get(BridgeConfiguration.INITIAL_CONNECT_ATTEMPTS).toString());
-      Assert.assertEquals("-1", jsonObject.get(BridgeConfiguration.RECONNECT_ATTEMPTS).toString());
-      Assert.assertEquals("10", jsonObject.get(BridgeConfiguration.RECONNECT_ATTEMPTS_ON_SAME_NODE).toString());
-      Assert.assertEquals("true", jsonObject.get(BridgeConfiguration.USE_DUPLICATE_DETECTION).toString());
-      Assert.assertEquals("10485760", jsonObject.get(BridgeConfiguration.CONFIRMATION_WINDOW_SIZE).toString());
-      Assert.assertEquals(Integer.toString(ActiveMQDefaultConfiguration.getDefaultBridgeProducerWindowSize()), jsonObject.get(BridgeConfiguration.PRODUCER_WINDOW_SIZE).toString());
+      assertEquals("2000", jsonObject.get(BridgeConfiguration.RETRY_INTERVAL).toString());
+      assertEquals("1.0", jsonObject.get(BridgeConfiguration.RETRY_INTERVAL_MULTIPLIER).toString());
+      assertEquals("-1", jsonObject.get(BridgeConfiguration.INITIAL_CONNECT_ATTEMPTS).toString());
+      assertEquals("-1", jsonObject.get(BridgeConfiguration.RECONNECT_ATTEMPTS).toString());
+      assertEquals("10", jsonObject.get(BridgeConfiguration.RECONNECT_ATTEMPTS_ON_SAME_NODE).toString());
+      assertEquals("true", jsonObject.get(BridgeConfiguration.USE_DUPLICATE_DETECTION).toString());
+      assertEquals("10485760", jsonObject.get(BridgeConfiguration.CONFIRMATION_WINDOW_SIZE).toString());
+      assertEquals(Integer.toString(ActiveMQDefaultConfiguration.getDefaultBridgeProducerWindowSize()), jsonObject.get(BridgeConfiguration.PRODUCER_WINDOW_SIZE).toString());
 
-      Assert.assertEquals("30000", jsonObject.get(BridgeConfiguration.CLIENT_FAILURE_CHECK_PERIOD).toString());
-      Assert.assertEquals("2000", jsonObject.get(BridgeConfiguration.MAX_RETRY_INTERVAL).toString());
-      Assert.assertEquals("102400", jsonObject.get(BridgeConfiguration.MIN_LARGE_MESSAGE_SIZE).toString());
-      Assert.assertEquals("30000", jsonObject.get(BridgeConfiguration.CALL_TIMEOUT).toString());
-      Assert.assertEquals("1", jsonObject.get(BridgeConfiguration.CONCURRENCY).toString());
+      assertEquals("30000", jsonObject.get(BridgeConfiguration.CLIENT_FAILURE_CHECK_PERIOD).toString());
+      assertEquals("2000", jsonObject.get(BridgeConfiguration.MAX_RETRY_INTERVAL).toString());
+      assertEquals("102400", jsonObject.get(BridgeConfiguration.MIN_LARGE_MESSAGE_SIZE).toString());
+      assertEquals("30000", jsonObject.get(BridgeConfiguration.CALL_TIMEOUT).toString());
+      assertEquals("1", jsonObject.get(BridgeConfiguration.CONCURRENCY).toString());
+      assertEquals("60000", jsonObject.get(BridgeConfiguration.PENDING_ACK_TIMEOUT).toString());
 
       // also should contain default non-null values of string fields
-      Assert.assertEquals("\"ACTIVEMQ.CLUSTER.ADMIN.USER\"", jsonObject.get(BridgeConfiguration.USER).toString());
-      Assert.assertEquals("\"CHANGE ME!!\"", jsonObject.get(BridgeConfiguration.PASSWORD).toString());
+      assertEquals("\"ACTIVEMQ.CLUSTER.ADMIN.USER\"", jsonObject.get(BridgeConfiguration.USER).toString());
+      assertEquals("\"CHANGE ME!!\"", jsonObject.get(BridgeConfiguration.PASSWORD).toString());
    }
 
    @Test
@@ -117,10 +125,10 @@ public class BridgeConfigurationTest {
       // create BridgeConfiguration instance from empty JSON string
       final String jsonString = "{\"name\": \"name\"}"; // name field is required
       BridgeConfiguration deserializedConfiguration = BridgeConfiguration.fromJSON(jsonString);
-      Assert.assertNotNull(deserializedConfiguration);
+      assertNotNull(deserializedConfiguration);
 
       // the deserialized object should return the same default values as a newly instantiated object
-      Assert.assertEquals(deserializedConfiguration, new BridgeConfiguration("name"));
+      assertEquals(deserializedConfiguration, new BridgeConfiguration("name"));
    }
 
    @Test
@@ -134,10 +142,10 @@ public class BridgeConfigurationTest {
       BridgeConfiguration configuration = BridgeConfiguration.fromJSON(builder.build().toString());
 
       // in deserialized object the fields should still remain null
-      Assert.assertNotNull(configuration);
-      Assert.assertEquals("name", configuration.getName());
-      Assert.assertNull(configuration.getUser());
-      Assert.assertNull(configuration.getPassword());
+      assertNotNull(configuration);
+      assertEquals("name", configuration.getName());
+      assertNull(configuration.getUser());
+      assertNull(configuration.getPassword());
    }
 
    @Test
@@ -151,8 +159,8 @@ public class BridgeConfigurationTest {
       JsonObject jsonObject = JsonLoader.readObject(new StringReader(jsonString));
 
       // after serialization the fields value should remain null
-      Assert.assertEquals(JsonValue.ValueType.NULL, jsonObject.get(BridgeConfiguration.USER).getValueType());
-      Assert.assertEquals(JsonValue.ValueType.NULL, jsonObject.get(BridgeConfiguration.PASSWORD).getValueType());
+      assertEquals(JsonValue.ValueType.NULL, jsonObject.get(BridgeConfiguration.USER).getValueType());
+      assertEquals(JsonValue.ValueType.NULL, jsonObject.get(BridgeConfiguration.PASSWORD).getValueType());
    }
 
    private static JsonObject createFullJsonObject() {
@@ -192,6 +200,8 @@ public class BridgeConfigurationTest {
       objectBuilder.add(BridgeConfiguration.CALL_TIMEOUT, 12);
       objectBuilder.add(BridgeConfiguration.ROUTING_TYPE, "MULTICAST");
       objectBuilder.add(BridgeConfiguration.CONCURRENCY, 1);
+      objectBuilder.add(BridgeConfiguration.CONFIGURATION_MANAGED, true);
+      objectBuilder.add(BridgeConfiguration.PENDING_ACK_TIMEOUT, 321);
 
       return objectBuilder.build();
    }
