@@ -347,7 +347,7 @@ public class FileConfigurationTest extends AbstractConfigurationTestBase {
          }
       }
 
-      assertEquals(5, conf.getConnectionRouters().size());
+      assertEquals(6, conf.getConnectionRouters().size());
       for (ConnectionRouterConfiguration bc : conf.getConnectionRouters()) {
          if (bc.getName().equals("simple-local")) {
             assertEquals(bc.getKeyType(), KeyType.CLIENT_ID);
@@ -367,6 +367,13 @@ public class FileConfigurationTest extends AbstractConfigurationTestBase {
             assertFalse(bc.getPoolConfiguration().isLocalTargetEnabled());
             assertEquals("connector1", bc.getPoolConfiguration().getStaticConnectors().get(0));
             assertNull(bc.getPoolConfiguration().getDiscoveryGroupName());
+         } else if (bc.getName().equals("simple-router-connector2")) {
+            assertEquals(bc.getKeyType(), KeyType.USER_NAME);
+            assertNull(bc.getLocalTargetFilter());
+            assertEquals(bc.getPolicyConfiguration().getName(), FirstElementPolicy.NAME);
+            assertFalse(bc.getPoolConfiguration().isLocalTargetEnabled());
+            assertEquals("connector2", bc.getPoolConfiguration().getStaticConnectors().get(0));
+            assertNull(bc.getPoolConfiguration().getDiscoveryGroupName());
          } else if (bc.getName().equals("consistent-hash-router")) {
             assertEquals(bc.getKeyType(), KeyType.SNI_HOST);
             assertEquals(bc.getKeyFilter(), "^[^.]+");
@@ -428,7 +435,7 @@ public class FileConfigurationTest extends AbstractConfigurationTestBase {
             assertEquals("org.foo.BridgeTransformer3", bc.getTransformerConfiguration().getClassName());
             assertEquals("bridgeTransformerValue1", bc.getTransformerConfiguration().getProperties().get("bridgeTransformerKey1"));
             assertEquals("bridgeTransformerValue2", bc.getTransformerConfiguration().getProperties().get("bridgeTransformerKey2"));
-
+            assertEquals(123456, bc.getPendingAckTimeout());
          }
       }
 
@@ -846,18 +853,15 @@ public class FileConfigurationTest extends AbstractConfigurationTestBase {
 
          final ThrowableHolder holder = new ThrowableHolder();
 
-         final Thread webappContextThread = new Thread(new Runnable() {
-            @Override
-            public void run() {
-               FileConfiguration fileConfiguration = new FileConfiguration();
+         final Thread webappContextThread = new Thread(() -> {
+            FileConfiguration fileConfiguration = new FileConfiguration();
 
-               try {
-                  FileDeploymentManager deploymentManager = new FileDeploymentManager(customConfiguration.getName());
-                  deploymentManager.addDeployable(fileConfiguration);
-                  deploymentManager.readConfiguration();
-               } catch (Exception e) {
-                  holder.t = e;
-               }
+            try {
+               FileDeploymentManager deploymentManager = new FileDeploymentManager(customConfiguration.getName());
+               deploymentManager.addDeployable(fileConfiguration);
+               deploymentManager.readConfiguration();
+            } catch (Exception e) {
+               holder.t = e;
             }
          });
 
