@@ -16,6 +16,15 @@
  */
 package org.apache.activemq.artemis.tests.integration.jms.client;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNotSame;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assumptions.assumeFalse;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
+
 import javax.jms.Connection;
 import javax.jms.ConnectionFactory;
 import javax.jms.JMSConsumer;
@@ -41,9 +50,8 @@ import org.apache.activemq.artemis.jms.client.ActiveMQMessage;
 import org.apache.activemq.artemis.jms.client.ActiveMQTextMessage;
 import org.apache.activemq.artemis.spi.core.protocol.RemotingConnection;
 import org.apache.activemq.artemis.tests.util.JMSTestBase;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * GroupingTest
@@ -53,7 +61,7 @@ public class GroupingTest extends JMSTestBase {
    private Queue queue;
 
    @Override
-   @Before
+   @BeforeEach
    public void setUp() throws Exception {
       super.setUp();
 
@@ -61,7 +69,7 @@ public class GroupingTest extends JMSTestBase {
    }
 
    protected void setProperty(Message message) {
-      ((ActiveMQMessage) message).getCoreMessage().putStringProperty(org.apache.activemq.artemis.api.core.Message.HDR_GROUP_ID, new SimpleString("foo"));
+      ((ActiveMQMessage) message).getCoreMessage().putStringProperty(org.apache.activemq.artemis.api.core.Message.HDR_GROUP_ID, SimpleString.of("foo"));
    }
 
    protected ConnectionFactory getCF() throws Exception {
@@ -123,8 +131,8 @@ public class GroupingTest extends JMSTestBase {
    @Test
    public void testGroupingWithJMS2Producer() throws Exception {
       ConnectionFactory fact = getCF();
-      Assume.assumeFalse("only makes sense withOUT auto-group", ((ActiveMQConnectionFactory) fact).isAutoGroup());
-      Assume.assumeTrue("only makes sense withOUT explicit group-id", ((ActiveMQConnectionFactory) fact).getGroupID() == null);
+      assumeFalse(((ActiveMQConnectionFactory) fact).isAutoGroup(), "only makes sense withOUT auto-group");
+      assumeTrue(((ActiveMQConnectionFactory) fact).getGroupID() == null, "only makes sense withOUT explicit group-id");
       final String groupID = UUID.randomUUID().toString();
       JMSContext ctx = addContext(getCF().createContext(JMSContext.SESSION_TRANSACTED));
 
@@ -175,7 +183,7 @@ public class GroupingTest extends JMSTestBase {
    @Test
    public void testManyGroups() throws Exception {
       ConnectionFactory fact = getCF();
-      Assume.assumeFalse("only makes sense withOUT auto-group", ((ActiveMQConnectionFactory) fact).isAutoGroup());
+      assumeFalse(((ActiveMQConnectionFactory) fact).isAutoGroup(), "only makes sense withOUT auto-group");
 
       Connection connection = fact.createConnection();
 
@@ -309,12 +317,12 @@ public class GroupingTest extends JMSTestBase {
    @Test
    public void testGroupBuckets() throws Exception {
       ConnectionFactory fact = getCF();
-      Assume.assumeFalse("only makes sense withOUT auto-group", ((ActiveMQConnectionFactory) fact).isAutoGroup());
-      Assume.assumeTrue("only makes sense withOUT explicit group-id", ((ActiveMQConnectionFactory) fact).getGroupID() == null);
+      assumeFalse(((ActiveMQConnectionFactory) fact).isAutoGroup(), "only makes sense withOUT auto-group");
+      assumeTrue(((ActiveMQConnectionFactory) fact).getGroupID() == null, "only makes sense withOUT explicit group-id");
 
       String testQueueName = getName() + "_bucket_group";
 
-      server.createQueue(new QueueConfiguration(testQueueName).setRoutingType(RoutingType.ANYCAST).setGroupBuckets(2));
+      server.createQueue(QueueConfiguration.of(testQueueName).setRoutingType(RoutingType.ANYCAST).setGroupBuckets(2));
 
       JMSContext ctx = addContext(getCF().createContext(JMSContext.SESSION_TRANSACTED));
 
@@ -391,11 +399,11 @@ public class GroupingTest extends JMSTestBase {
    @Test
    public void testGroupRebalance() throws Exception {
       ConnectionFactory fact = getCF();
-      Assume.assumeFalse("only makes sense withOUT auto-group", ((ActiveMQConnectionFactory) fact).isAutoGroup());
-      Assume.assumeTrue("only makes sense withOUT explicit group-id", ((ActiveMQConnectionFactory) fact).getGroupID() == null);
+      assumeFalse(((ActiveMQConnectionFactory) fact).isAutoGroup(), "only makes sense withOUT auto-group");
+      assumeTrue(((ActiveMQConnectionFactory) fact).getGroupID() == null, "only makes sense withOUT explicit group-id");
       String testQueueName = getName() + "_group_rebalance";
 
-      server.createQueue(new QueueConfiguration(testQueueName).setRoutingType(RoutingType.ANYCAST).setGroupRebalance(true));
+      server.createQueue(QueueConfiguration.of(testQueueName).setRoutingType(RoutingType.ANYCAST).setGroupRebalance(true));
 
       JMSContext ctx = addContext(getCF().createContext(JMSContext.SESSION_TRANSACTED));
 
@@ -528,11 +536,11 @@ public class GroupingTest extends JMSTestBase {
    @Test
    public void testGroupRebalancePauseDispatch() throws Exception {
       ConnectionFactory fact = getCF();
-      Assume.assumeFalse("only makes sense withOUT auto-group", ((ActiveMQConnectionFactory) fact).isAutoGroup());
-      Assume.assumeTrue("only makes sense withOUT explicit group-id", ((ActiveMQConnectionFactory) fact).getGroupID() == null);
+      assumeFalse(((ActiveMQConnectionFactory) fact).isAutoGroup(), "only makes sense withOUT auto-group");
+      assumeTrue(((ActiveMQConnectionFactory) fact).getGroupID() == null, "only makes sense withOUT explicit group-id");
       String testQueueName = getName() + "_group_rebalance";
 
-      server.createQueue(new QueueConfiguration(testQueueName).setRoutingType(RoutingType.ANYCAST).setGroupRebalance(true).setGroupRebalancePauseDispatch(true));
+      server.createQueue(QueueConfiguration.of(testQueueName).setRoutingType(RoutingType.ANYCAST).setGroupRebalance(true).setGroupRebalancePauseDispatch(true));
 
       JMSContext ctx = addContext(getCF().createContext(JMSContext.SESSION_TRANSACTED));
 
@@ -672,11 +680,11 @@ public class GroupingTest extends JMSTestBase {
    public void testGroupFirstKey() throws Exception {
       String customFirstGroupKey = "my-custom-key";
       ConnectionFactory fact = getCF();
-      Assume.assumeFalse("only makes sense withOUT auto-group", ((ActiveMQConnectionFactory) fact).isAutoGroup());
-      Assume.assumeTrue("only makes sense withOUT explicit group-id", ((ActiveMQConnectionFactory) fact).getGroupID() == null);
+      assumeFalse(((ActiveMQConnectionFactory) fact).isAutoGroup(), "only makes sense withOUT auto-group");
+      assumeTrue(((ActiveMQConnectionFactory) fact).getGroupID() == null, "only makes sense withOUT explicit group-id");
       String testQueueName = getName() + "_group_first_key";
 
-      server.createQueue(new QueueConfiguration(testQueueName).setRoutingType(RoutingType.ANYCAST).setGroupRebalance(true).setGroupFirstKey(customFirstGroupKey));
+      server.createQueue(QueueConfiguration.of(testQueueName).setRoutingType(RoutingType.ANYCAST).setGroupRebalance(true).setGroupFirstKey(customFirstGroupKey));
 
       JMSContext ctx = addContext(getCF().createContext(JMSContext.SESSION_TRANSACTED));
 
@@ -768,11 +776,11 @@ public class GroupingTest extends JMSTestBase {
    @Test
    public void testGroupDisable() throws Exception {
       ConnectionFactory fact = getCF();
-      Assume.assumeFalse("only makes sense withOUT auto-group", ((ActiveMQConnectionFactory) fact).isAutoGroup());
-      Assume.assumeTrue("only makes sense withOUT explicit group-id", ((ActiveMQConnectionFactory) fact).getGroupID() == null);
+      assumeFalse(((ActiveMQConnectionFactory) fact).isAutoGroup(), "only makes sense withOUT auto-group");
+      assumeTrue(((ActiveMQConnectionFactory) fact).getGroupID() == null, "only makes sense withOUT explicit group-id");
       String testQueueName = getName() + "_group_disable";
 
-      server.createQueue(new QueueConfiguration(testQueueName).setRoutingType(RoutingType.ANYCAST).setGroupBuckets(0));
+      server.createQueue(QueueConfiguration.of(testQueueName).setRoutingType(RoutingType.ANYCAST).setGroupBuckets(0));
 
       JMSContext ctx = addContext(getCF().createContext(JMSContext.SESSION_TRANSACTED));
 
@@ -867,7 +875,7 @@ public class GroupingTest extends JMSTestBase {
          MessageProducer producer = session.createProducer(queue);
 
 
-         QueueBinding queueBinding = (QueueBinding) server.getPostOffice().getBinding(SimpleString.toSimpleString(testQueueName));
+         QueueBinding queueBinding = (QueueBinding) server.getPostOffice().getBinding(SimpleString.of(testQueueName));
          assertEquals(4, queueBinding.getQueue().getGroupBuckets());
       } finally {
          connection.close();
@@ -896,7 +904,7 @@ public class GroupingTest extends JMSTestBase {
          MessageProducer producer = session.createProducer(queue);
 
 
-         QueueBinding queueBinding = (QueueBinding) server.getPostOffice().getBinding(SimpleString.toSimpleString(testQueueName));
+         QueueBinding queueBinding = (QueueBinding) server.getPostOffice().getBinding(SimpleString.of(testQueueName));
          assertTrue(queueBinding.getQueue().isGroupRebalance());
       } finally {
          connection.close();
@@ -925,7 +933,7 @@ public class GroupingTest extends JMSTestBase {
          MessageProducer producer = session.createProducer(queue);
 
 
-         QueueBinding queueBinding = (QueueBinding) server.getPostOffice().getBinding(SimpleString.toSimpleString(testQueueName));
+         QueueBinding queueBinding = (QueueBinding) server.getPostOffice().getBinding(SimpleString.of(testQueueName));
          assertEquals("my-custom-key", queueBinding.getQueue().getGroupFirstKey().toString());
       } finally {
          connection.close();
